@@ -4,6 +4,7 @@ import io
 import os
 import sys
 import shutil
+import time
 import tarfile
 import logging
 import requests
@@ -62,11 +63,26 @@ def get_local_md5_record(database_name):
     if os.path.exists(local_path):
         with open(os.path.join(VAR_DIR, database_name + ".md5"), "r") as fp:
             var_md5 = fp.read()
-        LOGGER.info("Got md5={var_md5} for local {database_name}.tar.gz")
+        LOGGER.info(f"Got md5={var_md5} for local {database_name}.tar.gz")
         return var_md5
     return False
 
 
+def get_database_age(database_path):
+    """Get the age in seconds since this MaxMind GeoLite2 database was written.
+
+    Args:
+        database_path: The path to the database.
+
+    Returns:
+        An integer representing the age in seconds of the MaxMind database.
+    """
+    if os.path.exists(database_path):
+        return time.time() - os.path.getmtime(database_path)
+    LOGGER.error(f"{database_path} does not exist.")
+    return False
+
+
 def update_databases(
     license_key=CONFIG["maxmind"]["license_key"],
     database_names=CONFIG["maxmind"]["database_names"],
@@ -189,19 +205,20 @@ def _validate_database_file_paths(
             LOGGER.warning(f"Couldn't find local or system '{db}' database")
     return valid_database_paths
 
+
 def get_database_locations(
     license_key=CONFIG["maxmind"]["license_key"],
     database_files=CONFIG["maxmind"]["local_database_files"],
     system_database_files=CONFIG["maxmind"]["system_default_database_files"],
-    **requests_kwargs
+    **requests_kwargs,
 ):
     """Located existing databases or try to download them.
 
     Local databases always override system databases.
     """
     database_file_paths = _validate_database_file_paths(
-            database_files=database_files, system_database_files=system_database_files
-        )
+        database_files=database_files, system_database_files=system_database_files
+    )
     if not database_file_paths:
         # try to download
         if not update_databases(license_key=license_key, **requests_kwargs):
@@ -213,6 +230,43 @@ def get_database_locations(
     return database_file_paths
 
 
+def are_database_files_up_to_date(
+    database_files=CONFIG["maxmind"]["local_database_files"],
+    system_database_files=CONFIG["maxmind"]["system_default_database_files"],
+):
+    """Are the databases old?
+
+    Considers databases to be current if they're younger than 7 days old.
+
+    Args:
+        database_files: list of any local GeoLite2 database file paths.
+        system_database_files: list of default locations for GeoLite2 databases.
+
+    Returns:
+        True if the databases are up-to-date. False otherwise.
+    """
+    database_file_path_map = database_file_paths = _validate_database_file_paths(
+        database_files=database_files, system_database_files=system_database_files
+    )
+    database_file_paths = database_file_path_map.values()
+
+    if not database_file_paths:
+        LOGGER.warning(f"no databases were found.")
+        return False
+
+    one_day = 86400  # seconds
+    # This is an all or nothing check.
+    up_to_date = True
+    for db_path in database_file_paths:
+        age = get_database_age(db_path)
+        if age > (7 * one_day):
+            days = int(age / one_day)
+            LOGGER.warning(f"{db_path} is more than {days} days old.")
+            up_to_date = False
+
+    return up_to_date
+
+
 class MaxMind_IP(object):
     """A convienice wrapper around the MaxMind Results for an IP address."""
 
@@ -304,8 +358,9 @@ class Client:
         # locate existing or try to download databases
         self.database_files = get_database_locations(
             license_key=license_key,
-            database_files=database_files, system_database_files=system_database_files,
-            **requests_kwargs
+            database_files=database_files,
+            system_database_files=system_database_files,
+            **requests_kwargs,
         )
 
         self.asn_reader = self.city_reader = self.country_reader = None
